Coverage for init.py: 100%

# Coverage for init.py : 100%

## 17 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1"""

2 All initializations like db = SQLAlchemy in this file

3"""

4 import os

5

6 from flask_login import LoginManager

7 from flask_mailman import Mail

8 from flask_marshmallow import Marshmallow

9 from flask_migrate import Migrate

10 from flask_sqlalchemy import SQLAlchemy

11 from flask_wtf.csrf import CSRFProtect

12

13 root_path = os.path.dirname(os.path.abspath(__file__)) # don't remove

14 static_path = os.path.join(root_path, "static") # don't remove

15 modules_path = os.path.join(root_path, "modules") # don't remove

16 themes_path = os.path.join(static_path, "themes") # don't remove

17

18 db = SQLAlchemy()

19 ma = Marshmallow()

20 login_manager = LoginManager()

21 migrate = Migrate()

22 mail = Mail()

23 csrf = CSRFProtect()